@@ -47,4 +47,6 @@
 /* MOD Player to use (program) */
 #define MOD_PLAYER 0
 
+/* the Xpm library is available */
+#define USE_XPM 0
 
