@@ -5,7 +5,7 @@
 
 #include "CoreOption.h"
 
-extern CoreOptionEntry * soundProcessEntries[];
+extern CoreOptionEntryList soundProcessEntries;
 
 
 #endif
