@@ -8,10 +8,11 @@ extern int _nFlames;
 
 int init_flames();
 
+extern CoreOptionEntryList generalFlameEntries;	
 
 class OptionGeneralFlame : public CoreOption {
 public:
-    OptionGeneralFlame(int buffer) : CoreOption(buffer, "flame-general", NULL, 0) {}
+    OptionGeneralFlame(int buffer) : CoreOption(buffer, "flame-general", generalFlameEntries) {}
 
     const char * text() const;
 };
