@@ -4,6 +4,12 @@
 #ifndef __IMATH_H
 #define __IMATH_H
 
+#include <math.h>
+
+#ifndef M_PI2
+#define M_PI2  6.2831385307
+#endif
+
 int init_imath();
     
 int Random(int range);
