@@ -12,6 +12,15 @@ int getkey();				/* get a key and return a code */
 
 void keys_x11(char *input, int state = 0);
 
+
+struct KeyAssoc {			// keyboard association table
+    const char * name;
+    int keyValue;
+};
+extern KeyAssoc keyAssoc[];
+extern int nKeyAssoc;
+
+
 #define CK_BASE			65536
 #define CK_FKT(x)		(CK_BASE + (x))
 #define CK_ENTER		(CK_BASE + 25)
