@@ -22,6 +22,11 @@
 #include "xcthugha.h"
 #endif
 #include "imath.h"
+#ifdef CTH_GL
+#include "glcthugha.h"
+#endif
+#include "keymap.h"
+#include "joystick.h"
 
 #include <unistd.h>
 #include <ctype.h>
@@ -61,6 +66,18 @@ enum option_nr {
     opt_dsp_sync,
     opt_no_dsp_sync,
     opt_no_snd_buffer,
+    opt_light,
+    opt_no_light,
+    opt_hints,
+    opt_dither,
+    opt_no_dither,
+    opt_background,
+    opt_no_background,
+    opt_fly,
+    opt_no_fly,
+    opt_keymap,
+    opt_shade,
+    opt_no_shade,
 };
 
 
@@ -104,6 +121,22 @@ struct option long_options[] = {
     { "no-snd-buffer",		0, 0, opt_no_snd_buffer},
     { "sound-buffer",		1, 0, opt_sound_buffer},
     { "no-sound-buffer",	0, 0, opt_no_snd_buffer},
+    { "once",			0, &soundPlayLoop, 0},
+    { "sound-once",		0, &soundPlayLoop, 0},
+    { "play-once",		0, &soundPlayLoop, 0},
+    { "snd-once",		0, &soundPlayLoop, 0},
+    { "no-once",		0, &soundPlayLoop, 1},
+    { "no-sound-once",		0, &soundPlayLoop, 1},
+    { "no-play-once",		0, &soundPlayLoop, 1},
+    { "no-snd-once",		0, &soundPlayLoop, 1},
+    { "loop",			0, &soundPlayLoop, 1},
+    { "play-loop",		0, &soundPlayLoop, 1},
+    { "sound-loop",		0, &soundPlayLoop, 1},
+    { "snd-loop",		0, &soundPlayLoop, 1},
+    { "no-loop",		0, &soundPlayLoop, 0},
+    { "no-play-loop",		0, &soundPlayLoop, 0},
+    { "no-sound-loop",		0, &soundPlayLoop, 0},
+    { "no-snd-loop",		0, &soundPlayLoop, 0},
 
 
     // CD options
@@ -156,6 +189,8 @@ struct option long_options[] = {
     { "sound-processing",	1, 0, 'm'},
     { "flame",			1, 0, 'f'},
     { "translation",		1, 0, 't'},
+    { "light",			1, 0, opt_light},
+    { "no-light",		1, 0, opt_no_light},
 #endif
 
     // buffer options
@@ -174,6 +209,8 @@ struct option long_options[] = {
     { "no-stretch",		0, &trans_stretch.value, 0},
     { "load-on-demand",		0, &transLoadOnDemand.value, 1},
     { "no-load-on-demand",	0, &transLoadOnDemand.value, 0},
+    { "load-late",		0, &transLoadLate.value, 1},
+    { "no-load-late",		0, &transLoadLate.value, 0},
     { "table",			1, 0, 'a'},
     { "border",			1, 0, opt_border},
 #endif
@@ -241,11 +278,28 @@ struct option long_options[] = {
 #ifdef CTH_GL
     { "mesh-size",		1, 0, opt_mesh_size },
     { "texture-quality",	1, 0, opt_texture_quality },
+    { "hints",			1, 0, opt_hints },
+    { "dither",			0, 0, opt_dither },
+    { "no-dither",		0, 0, opt_no_dither },
+    { "shade",			0, 0, opt_shade},
+    { "no-shade",		0, 0, opt_no_shade},
+    { "smooth",			0, 0, opt_shade},
+    { "flat",			0, 0, opt_no_shade},
+    { "no-smooth",		0, 0, opt_no_shade},
+    { "no-flat",		0, 0, opt_shade},
+    { "background",		1, 0, opt_background },
+    { "no-background",		0, 0, opt_no_background },
+    { "fly",			1, 0, opt_fly },
+    { "no-fly",			0, 0, opt_no_fly },
+    { "full-screen",		0, &fullScreen, 1},
+    { "no-full-screen",		0, &fullScreen, 0},
+    { "window",			0, &fullScreen, 0},
+    { "no-window",		0, &fullScreen, 1},
 #endif
 
-    
     // general options
     { "path",			1, 0, 'E'},
+    { "keymap",			1, 0, opt_keymap},
 #ifndef CTH_SERV
     { "dbl-load",		0, &double_load.value, 1},
     { "no-dbl-load",		0, &double_load.value, 0},
@@ -253,6 +307,9 @@ struct option long_options[] = {
     { "no-save",		0, &options_save.value, 0},
     { "prt-file",		1, 0, opt_prt_file},
 #endif
+    { "joystick",		0, &Joystick::useJoystick, 1},
+    { "no-joystick",		0, &Joystick::useJoystick, 0},
+    { "no-js",			0, &Joystick::useJoystick, 0},
     { "esc",			0, &key_esc, 1},
     { "no-esc",			0, &key_esc, 0},
     { "verbose",		2, 0, opt_verbose},
@@ -331,6 +388,13 @@ int do_param(int c, int value, char * str) {
 	CthughaBuffer::current->soundProcess.setInitialEntry(str);	
 	break;
 
+    case opt_light:
+	light.setInitialEntry(str);
+	break;
+    case opt_no_light:
+	light.setInitialEntry("locked:none");
+	break;
+
 #endif
 
     case '2':					/* Stereo */
@@ -478,6 +542,10 @@ int do_param(int c, int value, char * str) {
 	CLT_PORT = value; break;
 #endif
 
+    case opt_keymap:
+	strncpy(Keymap::keymapFile, str, PATH_MAX);
+	break;
+
 #if WITH_NETWORK == 1
     case 'W':					/* time to wait when server */
 	srv_wait_time.change(str);
@@ -586,6 +654,41 @@ int do_param(int c, int value, char * str) {
 	TextureQuality.change(str);
 	break;
 
+    case opt_hints:
+	Hints.change(str);
+	break;
+
+    case opt_dither:
+	Dither.change("on");
+	break;
+
+    case opt_no_dither:
+	Dither.change("off");
+	break;
+
+    case opt_shade:
+	Shade.change("smooth");
+	break;
+
+    case opt_no_shade:
+	Shade.change("flat");
+	break;
+
+    case opt_background:
+	background.setInitialEntry(str);
+	break;
+
+    case opt_no_background:
+	background.setInitialEntry("lock:off");
+	break;
+
+    case opt_fly:
+	fly.setInitialEntry(str);
+	break;
+
+    case opt_no_fly:
+	fly.setInitialEntry("lock:none");
+	break;
 #endif
 
     default:					/* error or help */
