@@ -29,11 +29,10 @@ public:
 
 
 
-
+extern CoreOptionEntryList pcxEntries;
 class OptionPCX : public CoreOption {
 public:
-    OptionPCX(int b, const char * n, CoreOptionEntry ** e, int nE) :
-	CoreOption(b, n, e, nE) {}
+    OptionPCX(int b, const char * n) : CoreOption(b, n, pcxEntries) {}
     void change(int by, int doSave) {
 	CoreOption::change(by, doSave);			// business as usuall
 	show_pcx();
