@@ -41,11 +41,14 @@ class TranslateOption : public CoreOption {
     //
     int * lodCommonTrans;
     FILE * lodPipe;
+    int lodPID;
     int lodLine;
     int lodCurrent;
-    
+
+    int openPipe(const char * command);
+
 public:
-    TranslateOption(int buffer, const char * name, CoreOptionEntry ** entries, int nEntries); 
+    TranslateOption(int buffer, const char * name); 
 
     virtual int operator()();
 
@@ -60,5 +63,6 @@ int init_translate();
 extern OptionOnOff use_translates;		/* allow translations */
 extern OptionOnOff trans_stretch;		/* allow stretching */
 extern OptionOnOff transLoadOnDemand;
+extern OptionOnOff transLoadLate;
 
 #endif
